@@ -18,7 +18,7 @@
 
 #include <sys/audioio.h>
 #include "inputmodule.h"
-#include "thread/thread.h"
+#include "common/thread/thread.h"
 #include <ogg/ogg.h>
 
 typedef struct
@@ -34,4 +34,3 @@ typedef struct
 input_module_t *sun_open_module(module_param_t *params);
 
 #endif  /* __IM_SUN_H__ */
-
